-- vim: ts=4 sw=4 ai et

-- We need to have the localization table set up before this file is loaded.
local L = Ammo.strings

local function mkchatoption (ord, disf)
    local t = {
        type = 'toggle',
        name = L["Chat"],
        desc = L["Provide warning in the default chat window."],
        order = ord,
        disabled = disf,
    }
    return t
end

local function mkwarnoption (ord, disf)
    local t = {
        type = 'toggle',
        name = L["Error frame"],
        desc = L["Provide warning in the standard error frame (top center of screen)."],
        order = ord,
        disabled = disf,
    }
    return t
end

local function mkvoiceoption (ord, disf)
    local t = {
        type = 'toggle',
        name = L["Voice"],
        desc = L["Provide vocal warning."],
        disabled = disf,
        order = ord,
    }
    return t
end

local function fcl ()
    return not Ammo.db.profile.current_low_enabled
end

local function fce ()
    return not Ammo.db.profile.current_exhausted_enabled
end

local function fae ()
    return not Ammo.db.profile.all_exhausted_enabled
end

local ammotable = {
    premium = L["Premium"],
    lowgrade = L["Low-grade"]
}

Ammo.cfghandler = {}

Ammo.config = {
    type = 'group',
    handler = Ammo.cfghandler,
    get = "GetVal", set = "SetVal",
    args = {
        general = {
            type = 'group',
            name = L["General settings"],
            args = {
                blurb = {
                    type = 'description',
                    order = 1,
                    name = L["Ammo-matique provides automated ammo handling - it can automatically reload for you if you run out of your current ammo type, and it can automatically select the suitable ammo type for any particular situation."],
                },
                blurb2 = {
                    type = 'description',
                    order = 2,
                    name = L["Ammo-matique uses two terms when referring to ammo - 'premium' and 'lowgrade'. Premium refers to the ammo type with the highest DPS that you have available. Conversely, lowgrade refers to the ammo type with the lowest DPS."],
                },
                blurb3 = {
                    type = 'description',
                    order = 3,
                    name = L["Tip: you can use /ammo to access Ammo-matique functionality from macros or the chat box."],
                },
                hdr = {
                    type = 'header',
                    name = "",
                    order = 19,
                },
                reload = {
                    type = 'toggle',
                    name = L["Auto-reload"],
                    desc = L["Automatically reload when current ammo is exhausted."],
                    order = 20,
                },
                switch = {
                    type = 'toggle',
                    name = L["Auto-switch"],
                    desc = L["Automatically switch ammo in PvE and/or PvP."],
                    order = 30,
                },
                notify = {
                    type = 'toggle',
                    name = L["Notifications"],
                    desc = L["Provide status notifications, e.g. when switching ammo, or (de)activating auto-reload."],
                    order = 40,
                },
                spacer = {
                    type = 'description',
                    order = 99,
                    name = "\n\n\n\n\n\n\n",
                },
                hdr2 = {
                    type = 'header',
                    name = "",
                    order = 100,
                },
                author = {
                    type = 'description',
                    name = "By Anyia of Horde Yakka (Jubei'Thos)\n",
                    order = 101,
                },
            }
        },
        warnings = {
            type = 'group',
            name = L["Ammo warnings"],
            args = {
                blurb = {
                    type = 'description',
                    order = 1,
                    name = L["Ammo-matique can provide warnings when you are running low or out of ammunition in a variety of ways. Select the ones you would like."],
                },
                voiceset = {
                    type = 'select',
                    order = 5,
                    name = L["Voice set"],
                    desc = L["Voice set to use if voice warnings are enabled."],
                    values = { male1 = L["Male"], female1 = L["Female"] },
                },
                current_low = {
                    type = 'group',
                    inline = true,
                    name = L["Low ammo warning"],
                    order = 10,
                    args = {
                        enabled = {
                            type = 'toggle',
                            name = L["Enabled"],
                            desc = L["Warn when the current ammo is running low."],
                            order = 10,
                        },
                        threshold = {
                            type = 'range',
                            name = L["Low ammo threshold"],
                            desc = L["Warn when current ammo falls below this value."],
                            order = 20,
                            min = 0, max = 2000, step = 20,
                            disabled = fcl,
                        },
                        ignoreme = {
                            type = 'description',
                            name = "",
                            order = 29,
                        },
                        text = mkchatoption (30, fcl),
                        warn = mkwarnoption (35, fcl),
                        voice = mkvoiceoption (40, fcl),
                    },
                }, -- End: Low ammo warning
                current_exhausted = {
                    type = 'group',
                    inline = true,
                    name = L["Ammo exhausted warning"],
                    order = 20,
                    args = {
                        enabled = {
                            type = 'toggle',
                            name = L["Enabled"],
                            desc = L["Warn when the current ammo is exhausted."],
                            order = 10,
                        },
                        ignoreme = {
                            type = 'description',
                            name = "",
                            order = 29,
                        },
                        text = mkchatoption (30, fce),
                        warn = mkwarnoption (35, fce),
                        voice = mkvoiceoption (40, fce),
                    },
                }, -- End current_exhausted
                all_exhausted = {
                    type = 'group',
                    inline = true,
                    name = L["All ammo exhausted warning"],
                    order = 30,
                    args = {
                        enabled = {
                            type = 'toggle',
                            name = L["Enabled"],
                            desc = L["Warn when all ammo is exhausted."],
                            order = 10,
                        },
                        ignoreme = {
                            type = 'description',
                            name = "",
                            order = 29,
                        },
                        text = mkchatoption (30, fae),
                        warn = mkwarnoption (35, fae),
                        voice = mkvoiceoption (40, fae),
                    },
                }, -- End all_exhausted
            }
        },
        pve = {
            type = 'group',
            name = L["PvE ammo switching"],
            disabled = function () return not Ammo.db.profile.general_switch end,
            args = {
                blurb = {
                    type = 'description',
                    order = 1,
                    name = L["Ammo-matique allows you to switch ammo depending on the type of mob you are fighting.\n\nNote: Once premium ammo has been switched in for a fight, it will stay equipped throughout the fight."],
                },
                bosses = {
                    type = 'group',
                    inline = true,
                    name = L["Bosses"],
                    order = 10,
                    args = {
                        enabled = {
                            type = 'toggle',
                            name = L["Enabled"],
                            desc = L["Switch ammo for bosses."],
                            order = 10,
                        },
                        ammotype = {
                            type = 'select',
                            name = L["Ammo type"],
                            desc = L["Ammo type to use when fighting bosses."],
                            order = 20,
                            disabled = function () return not Ammo.db.profile.bosses_enabled end,
                            values = ammotable,
                        }
                    },
                },
                elites = {
                    type = 'group',
                    inline = true,
                    name = L["Elites"],
                    order = 20,
                    args = {
                        enabled = {
                            type = 'toggle',
                            name = L["Enabled"],
                            desc = L["Switch ammo for elite mobs."],
                            order = 10,
                        },
                        ammotype = {
                            type = 'select',
                            name = L["Ammo type"],
                            desc = L["Ammo type to use when fighting elite mobs."],
                            order = 20,
                            disabled = function () return not Ammo.db.profile.elites_enabled end,
                            values = ammotable,
                        }
                    },
                },
                nonelites = {
                    type = 'group',
                    inline = true,
                    name = L["Non-elites"],
                    order = 30,
                    args = {
                        enabled = {
                            type = 'toggle',
                            name = L["Enabled"],
                            desc = L["Switch ammo for non-elite mobs."],
                            order = 10,
                        },
                        ammotype = {
                            type = 'select',
                            name = L["Ammo type"],
                            desc = L["Ammo type to use when fighting non-elite mobs."],
                            order = 20,
                            disabled = function () return not Ammo.db.profile.nonelites_enabled end,
                            values = ammotable,
                        },
                    },
                },
            },
        },
        pvp = {
            type = 'group',
            name = L["PvP ammo switching"],
            disabled = function () return not Ammo.db.profile.general_switch end,
            args = {
                blurb = {
                    type = 'description',
                    order = 1,
                    name = L["Whenever you engage (or prepare to engage) another player in combat, Ammo-matique can automatically switch in ammo for you based on the situation."],
                },
                arena = {
                    type = 'group',
                    inline = true,
                    name = L["Arena"],
                    order = 10,
                    args = {
                        enabled = {
                            type = 'toggle',
                            name = L["Enabled"],
                            desc = L["Switch ammo when engaging in an Arena."],
                            order = 10,
                        },
                        ammotype = {
                            type = 'select',
                            name = L["Ammo type"],
                            desc = L["Ammo type to use when engaging in an Arena."],
                            order = 20,
                            disabled = function () return not Ammo.db.profile.arena_enabled end,
                            values = ammotable,
                        },
                    },
                },
                bg = {
                    type = 'group',
                    inline = true,
                    name = L["Battlegrounds"],
                    order = 20,
                    args = {
                        enabled = {
                            type = 'toggle',
                            name = L["Enabled"],
                            desc = L["Switch ammo when engaging in Battlegrounds."],
                            order = 10,
                        },
                        ammotype = {
                            type = 'select',
                            name = L["Ammo type"],
                            desc = L["Ammo type to use when engaging in Battlegrounds."],
                            order = 20,
                            disabled = function () return not Ammo.db.profile.bg_enabled end,
                            values = ammotable,
                        },
                    },
                },
                world = {
                    type = 'group',
                    inline = true,
                    name = L["World PvP"],
                    order = 30,
                    args = {
                        enabled = {
                            type = 'toggle',
                            name = L["Enabled"],
                            desc = L["Switch ammo when engaging in world PvP."],
                            order = 10,
                        },
                        ammotype = {
                            type = 'select',
                            name = L["Ammo type"],
                            desc = L["Ammo type to use when engaging in world PvP."],
                            order = 20,
                            disabled = function () return not Ammo.db.profile.world_enabled end,
                            values = ammotable,
                        },
                    },
                },
            }
        },
    }
}

Ammo.defaults = {
    profile = {
        general_reload = true,
        general_switch = true,
        general_notify = true,
        warnings_voiceset = "female1",
        current_low_enabled = true,
        current_low_threshold = 400,
        current_low_text = true,
        current_low_warn = false,
        current_low_voice = true,
        current_exhausted_enabled = true,
        current_exhausted_text = true,
        current_exhausted_warn = false,
        current_exhausted_voice = true,
        all_exhausted_enabled = true,
        all_exhausted_text = true,
        all_exhausted_warn = false,
        all_exhausted_voice = true,
        bosses_enabled = true,
        bosses_ammotype = "premium",
        elites_enabled = true,
        elites_ammotype = "lowgrade",
        nonelites_enabled = true,
        nonelites_ammotype = "lowgrade",
        arena_enabled = true,
        arena_ammotype = "premium",
        bg_enabled = false,
        bg_ammotype = "lowgrade",
        world_enabled = false,
        world_ammotype = "lowgrade",
    }
}


function Ammo.cfghandler:GetVal (info)
    local varname = info[#info -1].."_"..info[#info]
    return Ammo.db.profile[varname]
end

function Ammo.cfghandler:SetVal (info, v)
    local varname = info[#info -1].."_"..info[#info]
    Ammo.db.profile[varname] = v
end

